%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Be-CODIS main file - Case MERS %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Version 3.0
% Release Date: 15/10/2018

% Workgroup: Benjamin Ivorra (A), Dine Ngom (B), ngel Manuel Ramos (A)
% Institutions:
% (A) MOMAT research group, IMI-Institute & Applied Mathematics Department. Complutense University of Madrid, Spain.
% (B) Dpartement de Mathmatiques, UFR des Sciences et Technologies, Universit Assane Seck de Ziguinchor & Laboratoire dAnalyse Numrique et dInformatique, Universit Gaston Berger de Saint Louis, Sngal.

% Contact for support: ivorra@mat.ucm.es

% License agreements:
% *******************
% The license includes the terms of the GNU General Public License V3.0,
% available at http://www.gnu.org/copyleft/gpl.html,
% plus the following restrictions: This software is for personal use
% and reserved to public research or educational purposes.
% Any professional utilization is forbidden without the authors' agreement.

% Free registering information:
% *****************************
% Be-CODIS will automatically generate a License key associated to your name. A question about the
% License agreements will be asked at the beginning of the first simulation.

% Details about the model:
% ************************
% For details about the model and each parameters please refer to the following Preprint:
% Be-CoDiS: A Mathematical Model to Predict the Risk of Human Diseases Spread Between CountriesValidation and Application to the 20142015 Ebola Virus Disease Epidemic
% Benjamin Ivorra, Dine Ngom, ngel Manuel Ramos
% Bulletin of Mathematical Biology
% September 2015, Volume 77, Issue 9, pp 16681704
% Preprint version:
% arXiv:1410.6153 [q-bio.PE], 2014
% http://arxiv.org/abs/1410.6153

% Provided Files:
% ***************
% becodisEBOLA.m: main M-script to be launched to run one simulation of
% be-codis. Contains the main parameters of the model. They can be modified
% at glance (see III and IV).
% disease-data-Ebola.mat andcountry-data.mat: data of the countries and disease (see II)
% becodismod.p: be-CODIS model crypted source file.
% Readme.txt: short introduction to run Be-CODIS
% Be-Codis - Mathematical model.pdf: preprint article detailing the model.

%%%%%%%%%%%%%%%%%% 
% Important note % 
%%%%%%%%%%%%%%%%%%

%%%%%% The parameters provided in the following are adapted to
%%%%%% the 2014-16 Ebola Virus Disease epidemic case starting from the
%%%%%% index cases in Guinea at December 2013. 
%%%%%% Furthermore, a recalibration of some parameters that better fits recent
%%%%%% EVD data is given. Calibrated parameters are commented and the sentence (CASE: RECENT EVD DATA)
%%%%%% is added at the end of the description of those modified parameters.
%%%%%% Remove the comments to run this particular case starting from February 1st, 2015.



%%%%%%%%%%%%%%%%%%%%%
% I. INITIALIZATION %
%%%%%%%%%%%%%%%%%%%%%

%%%%% I.1 Memmory initialization
initmat=1;becodismod;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% II. LOADING COUNTRIES AND DISEASE DATA %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%% II.1 Loading Data of each country
% Source of the data:
% Migration flow: http://www.global-migration.info
% Other indicators: http://data.worldbank.org/indicator

load('country-data')

% Considered variables:
% density: Matrix(Number of countries,1) - Density of each country (see country codes)
% densm: Matrix(Number of countries,Number of countries) - Percentage of the population migrating per day from one country (line) to other countries (column) (see country codes)
% ecom: Matrix(Number of countries,1) - GNI per capita of each country (see country codes)
% lifeexp: Matrix(Number of countries,1) - Life expectency of each country (see country codes)
% birthr: Matrix(Number of countries,1) - Birth rate per 1000 people of each country (see country codes)
% npop: Matrix(Number of countries,1) - Population size of each country (see country codes)
% sanit: Matrix(Number of countries,1) - Sanitary expenses per capita and per year of each country (see country codes)
% region: Structure - eographical data (names and boundaries) of each country (see country codes)

%%%%%% II.2 Loading Disease Data
% Source of the data:
% Data from the 2014-16 EVD epidemic:
% http://apps.who.int/ebola/en/current-situation/ebola-situation-report or http://apps.who.int/gho/data/node.ebola-sitrep or http://www.who.int/csr/disease/ebola/situation-reports/archive/en/

load('disease-data-Ebola')

% Considered variables:
% datosic: Matrix(Number of historical data, Number of countries) - Historical data of the number of cumulative detected infected cases by country: Line=date * column=country code
% datosid: Matrix(Number of historical data, Number of countries) - Historical data of the number of cumulative detected deaths due to the disease by country: Line=date * column=country code
% datosit: Vector(Number of historical data) - Matlab number corresponding to the date of each line of teh Matrix datosic and datosid


%To obtain the numerical codes associated to each country remove the
%comment to disp(lcountry)
%disp(lcountry)

%%%%%% II.2 Matrix initialization
initmat=2;becodismod

%%%%%%%%%%%%%%%%%%%%%%%%%
% III. MODEL PARAMETERS %
%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% III.1 Output Parameters
repsa='Be-CODIS-Result-EBOLA';    % Name of the folder to save the outputs
rootbecodis=cd;             % Name of the folder where Becodis must be launched
graphout=1;                 % Display graphical outputs: 0=Desactivate graphical outputs | 1= Draw all graphical outputs | 2=Draw only cumulative cases graphical outputs 
savegout=0;                 % Save Matlag Fig and Jpg files of each graphical outputs: 0=off | 1=on
textout=0;                  % Display textual output at each iteration: 0=off | 1=on
validout=1;                 % Display historic data on graphical outputs if available: 0=off | 1=on

%%%%% III.2  Duration of a person in each infected state  
dure=11.4;  % Mean duration of a person in the state E in days
duri=5.0;   % Mean duration of a person in the state I in days
durhr=5.0;  % Mean duration of a person from the state H to R in days
durhd=4.2;  % Mean duration of a person from the state H to D in days
varduri=3;  % Maximum reduciton (days) of person in the state I in days due to control measures
durd=2.0;   % Mean duration of a person in the state D in days
conva=13;   % Duration in days of the convalecense period

%%%%% III.3 Transmission rate Beta
Ebet=ecom./density;                                     % Variable used to estimate the transmission rate Beta of each country
Lbet=[60;92;143];                                       % Country code of countries with known values of transmission rate Beta 
Xbet=[0.1944;0.2649;0.2605];                            % Value of transmission rate Beta of countries in Lbet
%Xbet=[0.2068;0.3280;0.2118];                           % Value of transmission rate Beta of countries in Lbet (CASE: RECENT EVD DATA)
coefbetmin=0;                                           % Assumed minimum value of the transmission rate Beta
coefbetmax=10;                                          % Assumed minimum value of the transmission rate Beta
formbet=@(b,x) atan(b(1)*(1./x)+b(2))*abs(b(3))+b(4);   % Function formula used for fitting the transmission rate Beta
coefh=1/25;                                             % Ratio of the transmission rate of people in state H vs people in state I
coefd=1/1;                                              % Ratio of the transmission rate of people in state H vs people in state D

%%%%% III.4 Control parameter Kappa
Ecmes=sanit./density;                               % Variable used to estimate the control parameter Kappa of each country
Lcmes=[60;92;143];                                  % Country code of countries with known values of the control parameter Kappa 
Xcmes=[0.00125;0.0027;0.00227];                     % Value of the control parameter Kappa of countries in Lcmes
%Xcmes=[0.00131;0.00224;0.00227];                   % Value of thecontrol parameter Kappa of countries in Lcmes (CASE: RECENT EVD DATA)
coefmesmin=max(Xcmes);                              % Assumed minimum value of the control parameter Kappa
coefmesmax=10;                                      % Assumed minimum value of the control parameter Kappa
formmes=@(b,x) atan(b(1)*x+b(2))*abs(b(3))+b(4);    % Function formula used for fitting the control parameter Kappa

%%%%% III.5 Parameters for the Movement of people between countries
filtE=2e-3;         % Numerical filter threshold to avoid infection process in countries with low number of individual in E
filtT=2e-3;         % Numerical filter threshold to avoid the process of movement of countries with low number of individual in E
ampliftrans=2.1;    % Parameter multiplicating the movement matrix densm used to increase/decrease the movement fluxes 

% Delay (days) to wait in each country before the application of control
% measures and the first day for which H>=1. If not specified the delay is
% set to 0.
delaycm(60)=220;   
delaycm(92)=180;    
delaycm(143)=220;   
delaycm(115)=0;     

% Days of the beginning of the intensive control measures applied by the WHO
% organism according the initial date of the simulation datei (see country codes).
datelt(60,:)='14-Jul-2014';
datelt(92,:)='30-Jun-2014';
datelt(143,:)='09-Sep-2014';
datelt(49,:)='06-Oct-2014';
datelt(115,:)='20-Jul-2014';
datelt(141,:)='29-Aug-2014';
datelt(168,:)='30-Sep-2014';
datelt(104,:)='23-Oct-2014';

%%%%% III.6  Fatality rate parameters
edrmi=.25;          %Minimum fatality rate (%)
%edrmi=.32;         %Minimum fatality rate (%) (CASE: RECENT EVD DATA)
edrma=.728;         %Maximum fatality rate (%)
comesedr=0.53;      %Percentage (%) of the fatality rate that can be reduced by control measures 
 
%%%%% III.7 Dates of the simulation and stopping criteria
datei='06-Dec-2013';   % Date of beginning of the simulation
%datei='01-Feb-2015';  % Date of beginning of the simulation (CASE: RECENT EVD DATA)
datef='24-Apr-2025';   % Date of ending of the simulation
%datef='24-Apr-2015';   % Date of ending of the simulation (CASE: RECENT EVD DATA)
sclim=1;               % The algorithm is stopped when the number of people in state E, I, H and D in each country is lower than sclim

%%%%%%%%%%%%%%%%%%%%%%%%
% IV. RUNNING Be-CODIS %
%%%%%%%%%%%%%%%%%%%%%%%%

initmat=0;becodismod;

%%%%%%%%%%%%%%%%
% V.OUTPUTS %
%%%%%%%%%%%%%%%%

% V.1 Summary of the notations used in the Table (Matlab 2013 required) and Figures displayed by Be-CoDiS

% Code: Country code
% DateInf: First date of infection
% R0: Mean R 0value
% FCases: Final number of cumulative cases
% FDeaths: Final numebr of deaths
% ICases: Initial number of cumulative cases
% IDeaths: Initial numebr of deaths
% MNH: Maximum number of hospitalized people at the same time
% Dur: Duraiton of the epidemic in days
% TRS: Total risk of spread the disease to other countries
% Obs.: Historical observed data
% Pred.: DAta simulated by Be-CoDiS

% V.2 Main simulation Outputs are saved in: Output.mat

%ts: Real %Number of iterations of the model
%cumul: Matrix(Nf,ts) %Cumulative number of cases of each country at each time step
%cumuld: Matrix(Nf,ts) %Cumulative number of deaths of each country at each time step
%S: Matrix(Nf,ts) %Number of people in state S of each country at each time step
%E: Matrix(Nf,ts) %Number of people in state E of each country at each time step
%I: Matrix(Nf,ts) %Number of people in state I of each country at each time step
%H: Matrix(Nf,ts) %Number of people in state H of each country at each time step
%R: Matrix(Nf,ts) %Number of people in state R of each country at each time step
%D: Matrix(Nf,ts) %Number of people in state D of each country at each time step
%B: Matrix(Nf,ts) %Number of people in state B of each country at each time step
%V: Matrix(Nf,ts) %Number of hospitalized people (including people in state R) of each country at each time step
%R0: Matrix(Nf,ts) %Estimated R0 of each country at each time step
%Ri: Matrix(Nf,1) %Cumulative risk of EVD introduction of each country
%Rs: Matrix(Nf,1) %Cumulative risk of EVD spread to other countries of each country





